@@ -34,10 +34,12 @@ var (
 	Forbidden    = register(&Type{httpCode: http.StatusForbidden, meta: "forbidden"})
 	NotFound     = register(&Type{httpCode: http.StatusNotFound, meta: "not-found"})
 	Conflict     = register(&Type{httpCode: http.StatusConflict, meta: "internal"})
+	NotModified  = register(&Type{httpCode: http.StatusNotModified, meta: "not-modified"})
 
 	//500+
-	Internal = register(&Type{httpCode: http.StatusInternalServerError, meta: "internal"})
-	Timeout  = register(&Type{httpCode: http.StatusGatewayTimeout, meta: "timeout"})
+	Internal    = register(&Type{httpCode: http.StatusInternalServerError, meta: "internal"})
+	Timeout     = register(&Type{httpCode: http.StatusGatewayTimeout, meta: "timeout"})
+	Unavailable = register(&Type{httpCode: http.StatusServiceUnavailable, meta: "unavailable"})
 
 	//cached values
 	typesByHttpCode = newSyncMap[int, *Type]()
