@@ -28,3 +28,16 @@ func Is(err, target error) bool {
 func As(err error, target any) bool {
 	return errors.As(err, &target)
 }
+
+func Must(err error) {
+	if err != nil {
+		panic(err)
+	}
+}
+
+func Must1[T any](t T, err error) T {
+	if err != nil {
+		panic(err)
+	}
+	return t
+}
