@@ -25,7 +25,7 @@ type PullRequestIssue struct {
 	PullRequestId  string `json:"id" gorm:"primaryKey;type:varchar(255);comment:This key is generated based on details from the original plugin"` // format: <Plugin>:<Entity>:<PK0>:<PK1>
 	IssueId        string `gorm:"primaryKey;type:varchar(255)"`
 	PullRequestKey int
-	IssueKey       int
+	IssueKey       string `gorm:"type:varchar(255)"`
 	common.NoPKModel
 }
 
