@@ -23,6 +23,7 @@ import (
 	"github.com/apache/incubator-devlake/core/models/domainlayer/codequality"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/crossdomain"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/devops"
+	"github.com/apache/incubator-devlake/core/models/domainlayer/qa"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/ticket"
 )
 
@@ -53,6 +54,7 @@ func GetDomainTablesInfo() []dal.Tabler {
 		&codequality.CqFileMetrics{},
 		&codequality.CqIssueCodeBlock{},
 		&codequality.CqIssue{},
+		&codequality.CqIssueImpact{},
 		&codequality.CqProject{},
 		// crossdomain
 		&crossdomain.Account{},
@@ -93,5 +95,10 @@ func GetDomainTablesInfo() []dal.Tabler {
 		&ticket.IssueCustomArrayField{},
 		&ticket.Incident{},
 		&ticket.IncidentAssignee{},
+		// qa
+		&qa.QaProject{},
+		&qa.QaApi{},
+		&qa.QaTestCase{},
+		&qa.QaTestCaseExecution{},
 	}
 }
