@@ -26,9 +26,21 @@ type DomainEntity struct {
 	common.NoPKModel
 }
 
+type DomainEntityExtended struct {
+	Id string `json:"id" gorm:"primaryKey;type:varchar(500);comment:This key is generated based on details from the original plugin"` // format: <Plugin>:<Entity>:<PK0>:<PK1>
+	common.NoPKModel
+}
+
 func NewDomainEntity(id string) DomainEntity {
 	return DomainEntity{
 		Id:        id,
 		NoPKModel: common.NewNoPKModel(),
 	}
 }
+
+func NewDomainEntityExtended(id string) DomainEntityExtended {
+	return DomainEntityExtended{
+		Id:        id,
+		NoPKModel: common.NewNoPKModel(),
+	}
+}
