@@ -32,3 +32,24 @@ type Blueprint struct {
 func (Blueprint) TableName() string {
 	return "_devlake_blueprints"
 }
+
+type BlueprintConnection struct {
+	BlueprintId  uint64 `gorm:"primaryKey"`
+	PluginName   string `gorm:"primaryKey;type:varchar(255)"`
+	ConnectionId uint64 `gorm:"primaryKey"`
+}
+
+func (BlueprintConnection) TableName() string {
+	return "_devlake_blueprint_connections"
+}
+
+type BlueprintScope struct {
+	BlueprintId  uint64 `gorm:"primaryKey"`
+	PluginName   string `gorm:"primaryKey;type:varchar(255)"`
+	ConnectionId uint64 `gorm:"primaryKey"`
+	ScopeId      string `gorm:"primaryKey;type:varchar(255)"`
+}
+
+func (BlueprintScope) TableName() string {
+	return "_devlake_blueprint_scopes"
+}
