@@ -18,6 +18,9 @@ limitations under the License.
 package models
 
 import (
+	"encoding/json"
+	"time"
+
 	"github.com/apache/incubator-devlake/core/models/common"
 )
 
@@ -36,9 +39,9 @@ func (Project) TableName() string {
 }
 
 type BaseMetric struct {
-	PluginName   string `json:"pluginName" mapstructure:"pluginName" gorm:"primaryKey;type:varchar(255)" validate:"required"`
-	PluginOption string `json:"pluginOption" mapstructure:"pluginOption" gorm:"type:text"`
-	Enable       bool   `json:"enable" mapstructure:"enable" gorm:"type:boolean"`
+	PluginName   string          `json:"pluginName" mapstructure:"pluginName" gorm:"primaryKey;type:varchar(255)" validate:"required"`
+	PluginOption json.RawMessage `json:"pluginOption" mapstructure:"pluginOption" gorm:"type:json"`
+	Enable       bool            `json:"enable" mapstructure:"enable" gorm:"type:boolean"`
 }
 
 type BaseProjectMetricSetting struct {
@@ -59,6 +62,7 @@ type ApiInputProject struct {
 	BaseProject `mapstructure:",squash"`
 	Enable      *bool         `json:"enable" mapstructure:"enable"`
 	Metrics     []*BaseMetric `json:"metrics" mapstructure:"metrics"`
+	Blueprint   *Blueprint    `json:"blueprint" mapstructure:"blueprint"`
 }
 
 type ApiOutputProject struct {
@@ -67,3 +71,32 @@ type ApiOutputProject struct {
 	Blueprint    *Blueprint    `json:"blueprint" mapstructure:"blueprint"`
 	LastPipeline *Pipeline     `json:"lastPipeline,omitempty" mapstructure:"lastPipeline"`
 }
+
+type ApiProjectCheck struct {
+	Exist bool `json:"exist" mapstructure:"exist"`
+}
+
+type Store struct {
+	StoreKey   string          `gorm:"primaryKey;type:varchar(255)"`
+	StoreValue json.RawMessage `gorm:"type:json;serializer:json"`
+	CreatedAt  time.Time       `json:"createdAt" mapstructure:"createdAt"`
+	UpdatedAt  time.Time       `json:"updatedAt" mapstructure:"updatedAt"`
+}
+
+func (Store) TableName() string {
+	return "_devlake_store"
+}
+
+type ProjectScopeOutput struct {
+	Projects []ProjectScope `json:"projects"`
+	Count    int            `json:"count"`
+}
+
+type ProjectScope struct {
+	Name        string `json:"name"`
+	BlueprintId uint64 `json:"blueprintId"`
+	Scopes      []struct {
+		ScopeID   string `json:"scopeId"`
+		ScopeName string `json:"scopeName"`
+	} `json:"scopes"`
+}
