@@ -20,6 +20,7 @@ package plugin
 import (
 	"fmt"
 	"strings"
+	"sync"
 
 	"github.com/apache/incubator-devlake/core/context"
 	"github.com/apache/incubator-devlake/core/errors"
@@ -27,9 +28,14 @@ import (
 
 // Allowing plugin to know each other
 
-var plugins map[string]PluginMeta
+var (
+	plugins     map[string]PluginMeta
+	pluginMutex sync.RWMutex
+)
 
 func RegisterPlugin(name string, plugin PluginMeta) errors.Error {
+	pluginMutex.Lock()
+	defer pluginMutex.Unlock()
 	if plugins == nil {
 		plugins = make(map[string]PluginMeta)
 	}
@@ -74,13 +80,10 @@ func FindPluginNameBySubPkgPath(subPkgPath string) (string, errors.Error) {
 
 func InitPlugins(basicRes context.BasicRes) {
 	for pluginName, pluginMeta := range plugins {
-		basicRes.GetLogger().Info("try to init plugin: %s", pluginName)
 		if pluginEntry, ok := pluginMeta.(PluginInit); ok {
 			err := pluginEntry.Init(basicRes)
 			if err != nil {
 				panic(fmt.Errorf("failed to initialize plugin %v due to %w", pluginName, err))
-			} else {
-				basicRes.GetLogger().Info("init plugin: %s successfully", pluginName)
 			}
 		} else {
 			basicRes.GetLogger().Info("plugin: %s doesn't implement 'PluginInit', it will be skipped.", pluginName)
