@@ -228,7 +228,9 @@ func (t *DataFlowTester) Subtask(subtaskMeta plugin.SubTaskMeta, taskData interf
 // SubtaskContext creates a subtask context
 func (t *DataFlowTester) SubtaskContext(taskData interface{}) plugin.SubTaskContext {
 	syncPolicy := &models.SyncPolicy{
-		FullSync: true,
+		TriggerSyncPolicy: models.TriggerSyncPolicy{
+			FullSync: true,
+		},
 	}
 	return contextimpl.NewStandaloneSubTaskContext(context.Background(), runner.CreateBasicRes(t.Cfg, t.Log, t.Db), t.Name, taskData, t.Name, syncPolicy)
 }
@@ -460,7 +462,7 @@ func formatDbValue(value interface{}, nullable bool) string {
 	return ``
 }
 
-// ColumnWithRawData create an Column string with _raw_data_* appending
+// ColumnWithRawData create a Column string with _raw_data_* appending
 func ColumnWithRawData(column ...string) []string {
 	return append(
 		column,
