@@ -26,7 +26,6 @@ import (
 
 	"github.com/apache/incubator-devlake/core/dal"
 	"github.com/apache/incubator-devlake/core/errors"
-	"github.com/apache/incubator-devlake/core/models/common"
 	plugin "github.com/apache/incubator-devlake/core/plugin"
 	"github.com/merico-dev/graphql"
 )
@@ -79,8 +78,8 @@ type GraphqlCollectorArgs struct {
 	GetPageInfo func(query interface{}, args *GraphqlCollectorArgs) (*GraphqlQueryPageInfo, error)
 	BatchSize   int
 	// one of ResponseParser and ResponseParserEvenWhenDataErrors is required to parse response
-	ResponseParser               func(query interface{}, variables map[string]interface{}) ([]interface{}, error)
-	ResponseParserWithDataErrors func(query interface{}, variables map[string]interface{}, dataErrors []graphql.DataError) ([]interface{}, error)
+	ResponseParser    func(queryWrapper interface{}) ([]json.RawMessage, errors.Error)
+	IgnoreQueryErrors bool
 }
 
 // GraphqlCollector help you collect data from Graphql services
@@ -88,6 +87,7 @@ type GraphqlCollector struct {
 	*RawDataSubTask
 	args         *GraphqlCollectorArgs
 	workerErrors []error
+	batchSave    *BatchSave
 }
 
 // ErrFinishCollect is an error which will finish this collector
@@ -105,18 +105,24 @@ func NewGraphqlCollector(args GraphqlCollectorArgs) (*GraphqlCollector, errors.E
 	if args.GraphqlClient == nil {
 		return nil, errors.Default.New("ApiClient is required")
 	}
-	if args.ResponseParser == nil && args.ResponseParserWithDataErrors == nil {
+	if args.ResponseParser == nil {
 		return nil, errors.Default.New("one of ResponseParser and ResponseParserWithDataErrors is required")
 	}
+	if args.BatchSize == 0 {
+		args.BatchSize = 100
+	}
+	if args.InputStep == 0 {
+		args.InputStep = 1
+	}
 	apiCollector := &GraphqlCollector{
 		RawDataSubTask: rawDataSubTask,
 		args:           &args,
-	}
-	if args.BatchSize == 0 {
-		args.BatchSize = 500
-	}
-	if args.InputStep == 0 {
-		args.InputStep = 1
+		batchSave: errors.Must1(NewBatchSave(
+			args.Ctx,
+			reflect.TypeOf(&RawData{}),
+			args.BatchSize,
+			rawDataSubTask.table,
+		)),
 	}
 	return apiCollector, nil
 }
@@ -132,22 +138,8 @@ func (collector *GraphqlCollector) Execute() errors.Error {
 	if err != nil {
 		return errors.Default.Wrap(err, "error running auto-migrate")
 	}
-
-	divider := NewBatchSaveDivider(collector.args.Ctx, collector.args.BatchSize, collector.table, collector.params)
-
-	isIncremental := collector.args.Incremental
-	syncPolicy := collector.args.Ctx.TaskContext().SyncPolicy()
-	if syncPolicy != nil && syncPolicy.FullSync {
-		isIncremental = false
-	}
 	// flush data if not incremental collection
-	if isIncremental {
-		// re extract data for new scope config
-		err = collector.ExtractExistRawData(divider)
-		if err != nil {
-			collector.checkError(err)
-		}
-	} else {
+	if !collector.args.Incremental {
 		err = db.Delete(&RawData{}, dal.From(collector.table), dal.Where("params = ?", collector.params))
 		if err != nil {
 			return errors.Default.Wrap(err, "error deleting data from collector")
@@ -166,7 +158,7 @@ func (collector *GraphqlCollector) Execute() errors.Error {
 					collector.checkError(err)
 					break
 				}
-				collector.exec(divider, input)
+				collector.exec(input)
 			}
 		} else {
 			for !collector.HasError() {
@@ -182,12 +174,12 @@ func (collector *GraphqlCollector) Execute() errors.Error {
 				if inputs == nil {
 					break
 				}
-				collector.exec(divider, inputs)
+				collector.exec(inputs)
 			}
 		}
 	} else {
 		// or we just did it once
-		collector.exec(divider, nil)
+		collector.exec(nil)
 	}
 
 	logger.Debug("wait for all async api to finished")
@@ -202,11 +194,11 @@ func (collector *GraphqlCollector) Execute() errors.Error {
 		logger.Info("ended api collection without error")
 	}
 
-	err = divider.Close()
+	err = collector.batchSave.Close()
 	return err
 }
 
-func (collector *GraphqlCollector) exec(divider *BatchSaveDivider, input interface{}) {
+func (collector *GraphqlCollector) exec(input interface{}) {
 	inputJson, err := json.Marshal(input)
 	if err != nil {
 		collector.checkError(errors.Default.Wrap(err, `input can not be marshal to json`))
@@ -219,14 +211,14 @@ func (collector *GraphqlCollector) exec(divider *BatchSaveDivider, input interfa
 		Size:       collector.args.PageSize,
 	}
 	if collector.args.GetPageInfo != nil {
-		collector.fetchOneByOne(divider, reqData)
+		collector.fetchOneByOne(reqData)
 	} else {
-		collector.fetchAsync(divider, reqData, nil)
+		collector.fetchAsync(reqData, nil)
 	}
 }
 
 // fetchOneByOne fetches data of all pages for APIs that return paging information
-func (collector *GraphqlCollector) fetchOneByOne(divider *BatchSaveDivider, reqData *GraphqlRequestData) {
+func (collector *GraphqlCollector) fetchOneByOne(reqData *GraphqlRequestData) {
 	// fetch first page
 	var fetchNextPage func(query interface{}) errors.Error
 	fetchNextPage = func(query interface{}) errors.Error {
@@ -247,119 +239,16 @@ func (collector *GraphqlCollector) fetchOneByOne(divider *BatchSaveDivider, reqD
 					Input:     reqData.Input,
 					InputJSON: reqData.InputJSON,
 				}
-				collector.fetchAsync(divider, reqDataTemp, fetchNextPage)
+				collector.fetchAsync(reqDataTemp, fetchNextPage)
 				return nil
 			}, collector.checkError)
 		}
 		return nil
 	}
-	collector.fetchAsync(divider, reqData, fetchNextPage)
+	collector.fetchAsync(reqData, fetchNextPage)
 }
 
-// BatchSaveWithOrigin save the results and fill raw data origin for them
-func (collector *GraphqlCollector) BatchSaveWithOrigin(divider *BatchSaveDivider, results []interface{}, row *RawData) errors.Error {
-	// batch save divider
-	RAW_DATA_ORIGIN := "RawDataOrigin"
-	for _, result := range results {
-		// get the batch operator for the specific type
-		batch, err := divider.ForType(reflect.TypeOf(result))
-		if err != nil {
-			return err
-		}
-		// set raw data origin field
-		origin := reflect.ValueOf(result).Elem().FieldByName(RAW_DATA_ORIGIN)
-		if origin.IsValid() && origin.IsZero() {
-			origin.Set(reflect.ValueOf(common.RawDataOrigin{
-				RawDataTable:  collector.table,
-				RawDataId:     row.ID,
-				RawDataParams: row.Params,
-			}))
-		}
-		// records get saved into db when slots were max outed
-		err = batch.Add(result)
-		if err != nil {
-			return errors.Default.Wrap(err, "error adding result to batch")
-		}
-	}
-	return nil
-}
-
-// ExtractExistRawData will extract data from existing data from raw layer if increment
-func (collector *GraphqlCollector) ExtractExistRawData(divider *BatchSaveDivider) errors.Error {
-	// load data from database
-	db := collector.args.Ctx.GetDal()
-	logger := collector.args.Ctx.GetLogger()
-
-	clauses := []dal.Clause{
-		dal.From(collector.table),
-		dal.Where("params = ?", collector.params),
-		dal.Orderby("id ASC"),
-	}
-
-	count, err := db.Count(clauses...)
-	if err != nil {
-		return errors.Default.Wrap(err, "error getting count of clauses")
-	}
-	cursor, err := db.Cursor(clauses...)
-	if err != nil {
-		return errors.Default.Wrap(err, "error running DB query")
-	}
-	logger.Info("get data from %s where params=%s and got %d", collector.table, collector.params, count)
-	defer cursor.Close()
-
-	// progress
-	collector.args.Ctx.SetProgress(0, -1)
-	ctx := collector.args.Ctx.GetContext()
-	// iterate all rows
-	for cursor.Next() {
-		select {
-		case <-ctx.Done():
-			return errors.Convert(ctx.Err())
-		default:
-		}
-		// get the type of query and variables. For each iteration, the query should be a different object
-		query, variables, _ := collector.args.BuildQuery(nil)
-		row := &RawData{}
-		err = db.Fetch(cursor, row)
-		if err != nil {
-			return errors.Default.Wrap(err, "error fetching row")
-		}
-
-		err = errors.Convert(json.Unmarshal(row.Data, &query))
-		if err != nil {
-			return errors.Default.Wrap(err, `graphql collector unmarshal query failed`)
-		}
-		err = errors.Convert(json.Unmarshal(row.Input, &variables))
-		if err != nil {
-			return errors.Default.Wrap(err, `variables in graphql query can not unmarshal from json`)
-		}
-
-		var results []interface{}
-		if collector.args.ResponseParserWithDataErrors != nil {
-			results, err = errors.Convert01(collector.args.ResponseParserWithDataErrors(query, variables, nil))
-		} else {
-			results, err = errors.Convert01(collector.args.ResponseParser(query, variables))
-		}
-		if err != nil {
-			if errors.Is(err, ErrFinishCollect) {
-				logger.Info("existing data parser return ErrFinishCollect, but skip. rawId: #%d", row.ID)
-			} else {
-				return errors.Default.Wrap(err, "error calling plugin Extract implementation")
-			}
-		}
-		err = collector.BatchSaveWithOrigin(divider, results, row)
-		if err != nil {
-			return err
-		}
-
-		collector.args.Ctx.IncProgress(1)
-	}
-
-	// save the last batches
-	return divider.Close()
-}
-
-func (collector *GraphqlCollector) fetchAsync(divider *BatchSaveDivider, reqData *GraphqlRequestData, handler func(query interface{}) errors.Error) {
+func (collector *GraphqlCollector) fetchAsync(reqData *GraphqlRequestData, handler func(query interface{}) errors.Error) {
 	if reqData.Pager == nil {
 		reqData.Pager = &CursorPager{
 			SkipCursor: nil,
@@ -373,6 +262,7 @@ func (collector *GraphqlCollector) fetchAsync(divider *BatchSaveDivider, reqData
 	}
 
 	logger := collector.args.Ctx.GetLogger()
+	db := collector.args.Ctx.GetDal()
 	dataErrors, err := collector.args.GraphqlClient.Query(query, variables)
 	if err != nil {
 		if err == context.Canceled {
@@ -384,7 +274,7 @@ func (collector *GraphqlCollector) fetchAsync(divider *BatchSaveDivider, reqData
 		return
 	}
 	if len(dataErrors) > 0 {
-		if collector.args.ResponseParserWithDataErrors == nil {
+		if !collector.args.IgnoreQueryErrors {
 			for _, dataError := range dataErrors {
 				collector.checkError(errors.Default.Wrap(dataError, `graphql query got error`))
 			}
@@ -394,50 +284,37 @@ func (collector *GraphqlCollector) fetchAsync(divider *BatchSaveDivider, reqData
 	}
 	defer logger.Debug("fetchAsync >>> done for %v %v", query, variables)
 
-	paramsBytes, err := json.Marshal(query)
-	if err != nil {
-		collector.checkError(errors.Default.Wrap(err, `graphql collector marshal query failed`))
-		return
-	}
-	db := collector.args.Ctx.GetDal()
 	queryStr, _ := graphql.ConstructQuery(query, variables)
 	variablesJson, err := json.Marshal(variables)
 	if err != nil {
 		collector.checkError(errors.Default.Wrap(err, `variables in graphql query can not marshal to json`))
 		return
 	}
-	row := &RawData{
-		Params: collector.params,
-		Data:   paramsBytes,
-		Url:    queryStr,
-		Input:  variablesJson,
-	}
-	err = db.Create(row, dal.From(collector.table))
-	if err != nil {
-		collector.checkError(errors.Default.Wrap(err, `not created row table in graphql collector`))
-		return
-	}
 
-	var results []interface{}
-	if collector.args.ResponseParserWithDataErrors != nil {
-		results, err = collector.args.ResponseParserWithDataErrors(query, variables, dataErrors)
-	} else {
-		results, err = collector.args.ResponseParser(query, variables)
+	results, err := collector.args.ResponseParser(query)
+	for _, result := range results {
+		row := &RawData{
+			Params: collector.params,
+			Data:   result,
+			Url:    queryStr,
+			Input:  variablesJson,
+		}
+		// collector.batchSave.Add(row)
+		err = db.Create(row, dal.From(collector.table))
+		if err != nil {
+			collector.checkError(errors.Default.Wrap(err, `not created row table in graphql collector`))
+			return
+		}
 	}
 	if err != nil {
 		if errors.Is(err, ErrFinishCollect) {
-			logger.Info("collector finish by parser, rawId: #%d", row.ID)
+			logger.Info("collector finish by parser")
 			handler = nil
 		} else {
 			collector.checkError(errors.Default.Wrap(err, `not parsed response in graphql collector`))
 			return
 		}
 	}
-	err = collector.BatchSaveWithOrigin(divider, results, row)
-	if err != nil {
-		collector.checkError(err)
-		return
-	}
 
 	collector.args.Ctx.IncProgress(1)
 	if handler != nil {
