@@ -47,10 +47,25 @@ func init() {
 		logLevel = logrus.ErrorLevel
 	}
 	inner.SetLevel(logLevel)
-	inner.SetFormatter(&logrus.TextFormatter{
-		TimestampFormat: time.DateTime,
-		FullTimestamp:   true,
-	})
+
+	var formatter logrus.Formatter
+
+	format := os.Getenv("LOGGING_FORMAT")
+
+	switch format {
+	case "json":
+		formatter = &logrus.JSONFormatter{
+			TimestampFormat: time.DateTime,
+		}
+	default:
+		formatter = &logrus.TextFormatter{
+			TimestampFormat: time.DateTime,
+			FullTimestamp:   true,
+		}
+	}
+
+	inner.SetFormatter(formatter)
+
 	basePath := cfg.GetString("LOGGING_DIR")
 	if basePath == "" {
 		basePath = "./logs"
