@@ -94,7 +94,7 @@ func CollectDeployBuild(taskCtx plugin.SubTaskContext) errors.Error {
 	if err != nil {
 		return err
 	}
-	return collector.Execute()
+	return covertError(collector.Execute())
 }
 
 var CollectDeployBuildMeta = plugin.SubTaskMeta{
