@@ -45,7 +45,7 @@ type BitbucketIssue struct {
 	BitbucketCreatedAt time.Time
 	BitbucketUpdatedAt time.Time `gorm:"index"`
 	Severity           string    `gorm:"type:varchar(255)"`
-	Component          string    `gorm:"type:varchar(255)"`
+	Component          string    `gorm:"type:text"`
 	common.NoPKModel
 }
 
