@@ -19,12 +19,17 @@ package models
 
 import (
 	"github.com/apache/incubator-devlake/core/models/common"
+	"time"
 )
 
 type BitbucketPrCommit struct {
-	ConnectionId  uint64 `gorm:"primaryKey"`
-	CommitSha     string `gorm:"primaryKey;type:varchar(40)"`
-	PullRequestId int    `gorm:"primaryKey;autoIncrement:false"`
+	ConnectionId       uint64 `gorm:"primaryKey"`
+	RepoId             string `gorm:"primaryKey"` // PullRequestId is not unique across multiple repos of a connection
+	PullRequestId      int    `gorm:"primaryKey;autoIncrement:false"`
+	CommitSha          string `gorm:"primaryKey;type:varchar(40)"`
+	CommitAuthorName   string
+	CommitAuthorEmail  string
+	CommitAuthoredDate time.Time
 	common.NoPKModel
 }
 
