@@ -93,7 +93,7 @@ func GetQuery(reqData *api.RequestData) (url.Values, errors.Error) {
 }
 
 // GetQueryCreatedAndUpdated is a common GeyQuery for timeFilter and incremental
-func GetQueryCreatedAndUpdated(fields string, collectorWithState *api.ApiCollectorStateManager) func(reqData *api.RequestData) (url.Values, errors.Error) {
+func GetQueryCreatedAndUpdated(fields string, apiCollector *api.StatefulApiCollector) func(reqData *api.RequestData) (url.Values, errors.Error) {
 	return func(reqData *api.RequestData) (url.Values, errors.Error) {
 		query, err := GetQuery(reqData)
 		if err != nil {
@@ -102,8 +102,8 @@ func GetQueryCreatedAndUpdated(fields string, collectorWithState *api.ApiCollect
 		query.Set("fields", fields)
 		query.Set("sort", "created_on")
 
-		if collectorWithState.Since != nil {
-			query.Set("q", fmt.Sprintf("updated_on>=%s", collectorWithState.Since.Format(time.RFC3339)))
+		if apiCollector.GetSince() != nil {
+			query.Set("q", fmt.Sprintf("updated_on>=%s", apiCollector.GetSince().Format(time.RFC3339)))
 		}
 		return query, nil
 	}
@@ -164,7 +164,7 @@ func GetRawMessageFromResponse(res *http.Response) ([]json.RawMessage, errors.Er
 	return rawMessages.Values, nil
 }
 
-func GetPullRequestsIterator(taskCtx plugin.SubTaskContext, collectorWithState *api.ApiCollectorStateManager) (*api.DalCursorIterator, errors.Error) {
+func GetPullRequestsIterator(taskCtx plugin.SubTaskContext, sac *api.StatefulApiCollector) (*api.DalCursorIterator, errors.Error) {
 	db := taskCtx.GetDal()
 	data := taskCtx.GetData().(*BitbucketTaskData)
 	clauses := []dal.Clause{
@@ -175,8 +175,8 @@ func GetPullRequestsIterator(taskCtx plugin.SubTaskContext, collectorWithState *
 			data.Options.FullName, data.Options.ConnectionId,
 		),
 	}
-	if collectorWithState.IsIncremental && collectorWithState.Since != nil {
-		clauses = append(clauses, dal.Where("bitbucket_updated_at > ?", *collectorWithState.Since))
+	if sac.IsIncremental() && sac.GetSince() != nil {
+		clauses = append(clauses, dal.Where("bitbucket_updated_at > ?", *sac.GetSince()))
 	}
 
 	// construct the input iterator
@@ -188,7 +188,7 @@ func GetPullRequestsIterator(taskCtx plugin.SubTaskContext, collectorWithState *
 	return api.NewDalCursorIterator(db, cursor, reflect.TypeOf(BitbucketInput{}))
 }
 
-func GetIssuesIterator(taskCtx plugin.SubTaskContext, collectorWithState *api.ApiCollectorStateManager) (*api.DalCursorIterator, errors.Error) {
+func GetIssuesIterator(taskCtx plugin.SubTaskContext, sac *api.StatefulApiCollector) (*api.DalCursorIterator, errors.Error) {
 	db := taskCtx.GetDal()
 	data := taskCtx.GetData().(*BitbucketTaskData)
 	clauses := []dal.Clause{
@@ -199,8 +199,8 @@ func GetIssuesIterator(taskCtx plugin.SubTaskContext, collectorWithState *api.Ap
 			data.Options.FullName, data.Options.ConnectionId,
 		),
 	}
-	if collectorWithState.IsIncremental && collectorWithState.Since != nil {
-		clauses = append(clauses, dal.Where("bitbucket_updated_at > ?", *collectorWithState.Since))
+	if sac.IsIncremental() && sac.GetSince() != nil {
+		clauses = append(clauses, dal.Where("bitbucket_updated_at > ?", *sac.GetSince()))
 	}
 	// construct the input iterator
 	cursor, err := db.Cursor(clauses...)
@@ -211,7 +211,7 @@ func GetIssuesIterator(taskCtx plugin.SubTaskContext, collectorWithState *api.Ap
 	return api.NewDalCursorIterator(db, cursor, reflect.TypeOf(BitbucketInput{}))
 }
 
-func GetPipelinesIterator(taskCtx plugin.SubTaskContext, collectorWithState *api.ApiCollectorStateManager) (*api.DalCursorIterator, errors.Error) {
+func GetPipelinesIterator(taskCtx plugin.SubTaskContext, sac *api.StatefulApiCollector) (*api.DalCursorIterator, errors.Error) {
 	db := taskCtx.GetDal()
 	data := taskCtx.GetData().(*BitbucketTaskData)
 	clauses := []dal.Clause{
@@ -222,8 +222,8 @@ func GetPipelinesIterator(taskCtx plugin.SubTaskContext, collectorWithState *api
 			data.Options.FullName, data.Options.ConnectionId,
 		),
 	}
-	if collectorWithState.IsIncremental && collectorWithState.Since != nil {
-		clauses = append(clauses, dal.Where("bitbucket_complete_on > ?", *collectorWithState.Since))
+	if sac.IsIncremental() && sac.GetSince() != nil {
+		clauses = append(clauses, dal.Where("bitbucket_complete_on > ?", *sac.GetSince()))
 	}
 	// construct the input iterator
 	cursor, err := db.Cursor(clauses...)
