@@ -86,6 +86,7 @@ func ConvertPullRequests(taskCtx plugin.SubTaskContext) errors.Error {
 				BaseCommitSha:  pr.BaseCommitSha,
 				HeadRef:        pr.HeadRef,
 				HeadCommitSha:  pr.HeadCommitSha,
+				MergedByName:   pr.MergedByName,
 			}
 			switch pr.State {
 			case "OPEN":
@@ -97,6 +98,9 @@ func ConvertPullRequests(taskCtx plugin.SubTaskContext) errors.Error {
 			default:
 				domainPr.Status = pr.State
 			}
+			if pr.MergedById != "" && pr.State == "MERGED" {
+				domainPr.MergedById = domainUserIdGen.Generate(data.Options.ConnectionId, pr.MergedById)
+			}
 
 			return []interface{}{
 				domainPr,
