@@ -72,7 +72,7 @@ func TestCircleciWorkflow(t *testing.T) {
 		devops.CICDPipeline{},
 		e2ehelper.TableOptions{
 			CSVRelPath:   "./snapshot_tables/cicd_pipelines.csv",
-			IgnoreFields: []string{"finished_date", "created_date"},
+			IgnoreFields: []string{"finished_date", "created_date", "is_child"},
 			IgnoreTypes:  []interface{}{domainlayer.DomainEntity{}},
 		},
 	)
