@@ -18,6 +18,9 @@ limitations under the License.
 package tasks
 
 import (
+	"encoding/json"
+	"net/http"
+
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/plugin"
 	"github.com/apache/incubator-devlake/helpers/pluginhelper/api"
@@ -38,15 +41,41 @@ var CollectPipelinesMeta = plugin.SubTaskMeta{
 func CollectPipelines(taskCtx plugin.SubTaskContext) errors.Error {
 	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_PIPELINE_TABLE)
 	logger := taskCtx.GetLogger()
+	timeAfter := rawDataSubTaskArgs.Ctx.TaskContext().SyncPolicy().TimeAfter
 	logger.Info("collect pipelines")
-	collector, err := api.NewApiCollector(api.ApiCollectorArgs{
-		RawDataSubTaskArgs:    *rawDataSubTaskArgs,
-		ApiClient:             data.ApiClient,
-		UrlTemplate:           "/v2/project/{{ .Params.ProjectSlug }}/pipeline",
-		PageSize:              int(data.Options.PageSize),
-		GetNextPageCustomData: ExtractNextPageToken,
-		Query:                 BuildQueryParamsWithPageToken,
-		ResponseParser:        ParseCircleciPageTokenResp,
+	collector, err := api.NewStatefulApiCollectorForFinalizableEntity(api.FinalizableApiCollectorArgs{
+		RawDataSubTaskArgs: *rawDataSubTaskArgs,
+		ApiClient:          data.ApiClient,
+		CollectNewRecordsByList: api.FinalizableApiCollectorListArgs{
+			PageSize:              int(data.Options.PageSize),
+			GetNextPageCustomData: ExtractNextPageToken,
+			FinalizableApiCollectorCommonArgs: api.FinalizableApiCollectorCommonArgs{
+				UrlTemplate: "/v2/project/{{ .Params.ProjectSlug }}/pipeline",
+				Query:       BuildQueryParamsWithPageToken,
+				ResponseParser: func(res *http.Response) ([]json.RawMessage, errors.Error) {
+					data := CircleciPageTokenResp[[]json.RawMessage]{}
+					err := api.UnmarshalResponse(res, &data)
+
+					if err != nil {
+						return nil, err
+					}
+					filteredItems := []json.RawMessage{}
+					for _, item := range data.Items {
+						pipelineCreatedAt, err := extractCreatedAt(item)
+
+						if err != nil {
+							return nil, err
+						}
+						if pipelineCreatedAt.Before(*timeAfter) {
+							return filteredItems, api.ErrFinishCollect
+						}
+						filteredItems = append(filteredItems, item)
+					}
+					return filteredItems, nil
+				},
+			},
+			GetCreated: extractCreatedAt,
+		},
 	})
 	if err != nil {
 		logger.Error(err, "collect pipelines error")
