@@ -31,11 +31,12 @@ func main() {
 	cmd := &cobra.Command{Use: "dora"}
 
 	projectName := cmd.Flags().StringP("projectName", "p", "", "project name")
+	timeAfter := cmd.Flags().StringP("timeAfter", "a", "", "collect data that are created after specified time, ie 2006-01-02T15:04:05Z")
 
 	cmd.Run = func(cmd *cobra.Command, args []string) {
 		runner.DirectRun(cmd, args, PluginEntry, map[string]interface{}{
 			"projectName": *projectName,
-		})
+		}, *timeAfter)
 	}
 	runner.RunCmd(cmd)
 }
