@@ -25,5 +25,7 @@ import (
 func All() []plugin.MigrationScript {
 	return []plugin.MigrationScript{
 		new(addDoraBenchmark),
+		new(fixDoraBenchmarkMetric),
+		new(adddoraBenchmark2023),
 	}
 }
