@@ -44,7 +44,7 @@ var _ interface {
 
 var _ plugin.PluginSource = (*Gitee)(nil)
 
-type Gitee string
+type Gitee struct{}
 
 func (p Gitee) Connection() dal.Tabler {
 	return &models.GiteeConnection{}
@@ -196,6 +196,9 @@ func (p Gitee) ApiResources() map[string]map[string]plugin.ApiResourceHandler {
 			"PATCH":  api.PatchConnection,
 			"DELETE": api.DeleteConnection,
 		},
+		"connections/:connectionId/test": {
+			"POST": api.TestExistingConnection,
+		},
 	}
 }
 
