@@ -19,11 +19,13 @@ package tasks
 
 import (
 	"encoding/json"
+	"strings"
+
 	"github.com/apache/incubator-devlake/core/errors"
+	"github.com/apache/incubator-devlake/core/models/common"
 	"github.com/apache/incubator-devlake/core/plugin"
 	"github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 	"github.com/apache/incubator-devlake/plugins/gitee/models"
-	"strings"
 )
 
 var ExtractApiPullRequestCommitsMeta = plugin.SubTaskMeta{
@@ -54,12 +56,12 @@ type PullRequestCommit struct {
 	Author struct {
 		Name  string
 		Email string
-		Date  api.Iso8601Time
+		Date  common.Iso8601Time
 	}
 	Committer struct {
 		Name  string
 		Email string
-		Date  api.Iso8601Time
+		Date  common.Iso8601Time
 	}
 	Message      string
 	CommentCount int `json:"comment_count"`
