@@ -18,6 +18,8 @@ limitations under the License.
 package store
 
 import (
+	"reflect"
+
 	"github.com/apache/incubator-devlake/core/context"
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/models/common"
@@ -25,7 +27,6 @@ import (
 	"github.com/apache/incubator-devlake/core/models/domainlayer/code"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/crossdomain"
 	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
-	"reflect"
 )
 
 const BathSize = 100
@@ -37,6 +38,7 @@ type Database struct {
 }
 
 func NewDatabase(basicRes context.BasicRes, repoId string) *Database {
+
 	database := &Database{
 		table:  "gitextractor",
 		params: repoId,
@@ -55,6 +57,10 @@ func (d *Database) updateRawDataFields(rawData *common.RawDataOrigin) {
 	rawData.RawDataParams = d.params
 }
 
+func (d *Database) SetIncrementalMode(incrementalMode bool) {
+	d.driver.SetIncrementalMode(incrementalMode)
+}
+
 func (d *Database) RepoCommits(repoCommit *code.RepoCommit) errors.Error {
 	batch, err := d.driver.ForType(reflect.TypeOf(repoCommit))
 	if err != nil {
@@ -87,7 +93,7 @@ func (d *Database) Commits(commit *code.Commit) errors.Error {
 	if err != nil {
 		return err
 	}
-	d.updateRawDataFields(&account.RawDataOrigin)
+	d.updateRawDataFields(&commit.RawDataOrigin)
 	return commitBatch.Add(commit)
 }
 
