@@ -18,13 +18,18 @@ limitations under the License.
 package models
 
 import (
+	"time"
+
 	"github.com/apache/incubator-devlake/core/models/common"
 )
 
 type GithubPrCommit struct {
-	ConnectionId  uint64 `gorm:"primaryKey"`
-	CommitSha     string `gorm:"primaryKey;type:varchar(40)"`
-	PullRequestId int    `gorm:"primaryKey;autoIncrement:false"`
+	ConnectionId       uint64 `gorm:"primaryKey"`
+	CommitSha          string `gorm:"primaryKey;type:varchar(40)"`
+	PullRequestId      int    `gorm:"primaryKey;autoIncrement:false"`
+	CommitAuthorName   string `gorm:"type:varchar(255)"` // Author name
+	CommitAuthorEmail  string `gorm:"type:varchar(255)"` // Author email
+	CommitAuthoredDate time.Time
 	common.NoPKModel
 }
 
