@@ -42,7 +42,7 @@ type SimpleAccountWithId struct {
 }
 
 var CollectAccountOrgMeta = plugin.SubTaskMeta{
-	Name:             "collectAccountOrg",
+	Name:             "Collect User Org",
 	EntryPoint:       CollectAccountOrg,
 	EnabledByDefault: true,
 	Description:      "Collect accounts org data from Github api, does not support either timeFilter or diffSync.",
@@ -98,6 +98,12 @@ func CollectAccountOrg(taskCtx plugin.SubTaskContext) errors.Error {
 			res.Body.Close()
 			return []json.RawMessage{body}, nil
 		},
+		AfterResponse: func(res *http.Response) errors.Error {
+			if res.StatusCode == http.StatusNotFound {
+				return api.ErrIgnoreAndContinue
+			}
+			return nil
+		},
 	})
 
 	if err != nil {
