@@ -35,7 +35,7 @@ func init() {
 }
 
 var ExtractApiIssuesMeta = plugin.SubTaskMeta{
-	Name:             "extractApiIssues",
+	Name:             "Extract Issues",
 	EntryPoint:       ExtractApiIssues,
 	EnabledByDefault: true,
 	Description:      "Extract raw Issues data into tool layer table github_issues",
