@@ -45,7 +45,7 @@ type GitlabIssue struct {
 	GitlabCreatedAt time.Time
 	GitlabUpdatedAt time.Time `gorm:"index"`
 	Severity        string    `gorm:"type:varchar(255)"`
-	Component       string    `gorm:"type:varchar(255)"`
+	Component       string    `gorm:"type:text"`
 	TimeEstimate    *int64
 	TotalTimeSpent  *int64
 	common.NoPKModel
