@@ -23,6 +23,10 @@ import (
 	"github.com/apache/incubator-devlake/core/models/common"
 )
 
+const (
+	PipelineSourceParentPipeline = "parent_pipeline"
+)
+
 type GitlabPipeline struct {
 	ConnectionId uint64 `gorm:"primaryKey"`
 
@@ -45,10 +49,16 @@ type GitlabPipeline struct {
 	Environment string `gorm:"type:varchar(255)"`
 
 	IsDetailRequired bool
+	Source           string
 
 	common.NoPKModel
 }
 
+func (gitlabPipeline GitlabPipeline) GenerateIsChild() bool {
+	return gitlabPipeline.Source == PipelineSourceParentPipeline
+
+}
+
 func (GitlabPipeline) TableName() string {
 	return "_tool_gitlab_pipelines"
 }
@@ -63,6 +73,8 @@ type GitlabPipelineProject struct {
 	GitlabCreatedAt *time.Time
 	GitlabUpdatedAt *time.Time
 	common.NoPKModel
+
+	Source string
 }
 
 func (GitlabPipelineProject) TableName() string {
