@@ -22,10 +22,9 @@ import (
 )
 
 type GitlabReviewer struct {
-	ConnectionId uint64 `gorm:"primaryKey"`
-
-	GitlabId       int    `gorm:"primaryKey"`
-	MergeRequestId int    `gorm:"index"`
+	ConnectionId   uint64 `gorm:"primaryKey"`
+	ReviewerId     int    `gorm:"primaryKey"`
+	MergeRequestId int    `gorm:"primaryKey"`
 	ProjectId      int    `gorm:"index"`
 	Name           string `gorm:"type:varchar(255)"`
 	Username       string `gorm:"type:varchar(255)"`
