@@ -18,7 +18,6 @@ limitations under the License.
 package tasks
 
 import (
-	"encoding/json"
 	"regexp"
 
 	"github.com/apache/incubator-devlake/core/errors"
@@ -37,11 +36,12 @@ var ExtractApiMergeRequestDetailsMeta = plugin.SubTaskMeta{
 	EnabledByDefault: true,
 	Description:      "Extract raw merge request Details data into tool layer table GitlabMergeRequest and GitlabReviewer",
 	DomainTypes:      []string{plugin.DOMAIN_TYPE_CODE_REVIEW},
-	Dependencies:     []*plugin.SubTaskMeta{&ExtractApiCommitsMeta},
+	Dependencies:     []*plugin.SubTaskMeta{&CollectApiMergeRequestDetailsMeta},
 }
 
-func ExtractApiMergeRequestDetails(taskCtx plugin.SubTaskContext) errors.Error {
-	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_MERGE_REQUEST_DETAIL_TABLE)
+func ExtractApiMergeRequestDetails(subtaskCtx plugin.SubTaskContext) errors.Error {
+	subtaskCommonArgs, data := CreateSubtaskCommonArgs(subtaskCtx, RAW_MERGE_REQUEST_DETAIL_TABLE)
+	db := subtaskCtx.GetDal()
 	config := data.Options.ScopeConfig
 	var labelTypeRegex *regexp.Regexp
 	var labelComponentRegex *regexp.Regexp
@@ -60,15 +60,14 @@ func ExtractApiMergeRequestDetails(taskCtx plugin.SubTaskContext) errors.Error {
 			return errors.Default.Wrap(err, "regexp Compile prComponent failed")
 		}
 	}
-	extractor, err := api.NewApiExtractor(api.ApiExtractorArgs{
-		RawDataSubTaskArgs: *rawDataSubTaskArgs,
-		Extract: func(row *api.RawData) ([]interface{}, errors.Error) {
-			mr := &MergeRequestRes{}
-			err := errors.Convert(json.Unmarshal(row.Data, mr))
-			if err != nil {
-				return nil, err
-			}
-
+	subtaskCommonArgs.SubtaskConfig = map[string]string{
+		"prType":      prType,
+		"prComponent": prComponent,
+	}
+	extractor, err := api.NewStatefulApiExtractor(&api.StatefulApiExtractorArgs[MergeRequestRes]{
+		SubtaskCommonArgs: subtaskCommonArgs,
+		BeforeExtract:     beforeExtractMr(db, data),
+		Extract: func(mr *MergeRequestRes, row *api.RawData) ([]interface{}, errors.Error) {
 			gitlabMergeRequest, err := convertMergeRequest(mr)
 			if err != nil {
 				return nil, err
