@@ -90,6 +90,7 @@ func (p Jira) GetTablesInfo() []dal.Tabler {
 		&models.JiraIssueComment{},
 		&models.JiraIssueRelationship{},
 		&models.JiraScopeConfig{},
+		&models.JiraIssueField{},
 	}
 }
 
@@ -103,6 +104,9 @@ func (p Jira) Name() string {
 
 func (p Jira) SubTaskMetas() []plugin.SubTaskMeta {
 	return []plugin.SubTaskMeta{
+		tasks.CollectIssueFieldsMeta,
+		tasks.ExtractIssueFieldsMeta,
+
 		tasks.CollectBoardFilterBeginMeta,
 
 		tasks.CollectStatusMeta,
