@@ -17,16 +17,25 @@ limitations under the License.
 
 package models
 
-import "time"
+import (
+	"github.com/apache/incubator-devlake/core/models/common"
+	"time"
+)
 
-type IssueComment struct {
+type JiraIssueComment struct {
+	common.NoPKModel
 	ConnectionId       uint64 `gorm:"primaryKey"`
 	IssueId            uint64 `gorm:"primarykey"`
 	ComentId           string `gorm:"primarykey"`
 	Self               string `gorm:"type:varchar(255)"`
 	Body               string
-	CreatorAccountId   string     `gorm:"type:varchar(255)"`
-	CreatorDisplayName string     `gorm:"type:varchar(255)"`
-	Created            *time.Time `json:"created"`
-	Updated            *time.Time `json:"updated"`
+	CreatorAccountId   string    `gorm:"type:varchar(255)"`
+	CreatorDisplayName string    `gorm:"type:varchar(255)"`
+	Created            time.Time `json:"created"`
+	Updated            time.Time `json:"updated"`
+	IssueUpdated       *time.Time
+}
+
+func (JiraIssueComment) TableName() string {
+	return "_tool_jira_issue_comments"
 }
