@@ -20,8 +20,8 @@ package api
 import (
 	"github.com/apache/incubator-devlake/core/errors"
 	coreModels "github.com/apache/incubator-devlake/core/models"
-	"github.com/apache/incubator-devlake/core/models/domainlayer/devops"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/didgen"
+	"github.com/apache/incubator-devlake/core/models/domainlayer/ticket"
 	"github.com/apache/incubator-devlake/core/plugin"
 	"github.com/apache/incubator-devlake/core/utils"
 	"github.com/apache/incubator-devlake/helpers/pluginhelper/api"
@@ -96,7 +96,7 @@ func makeScopesV200(
 		id := idgen.Generate(connection.ID, scope.Id)
 
 		if utils.StringsContains(scopeConfig.Entities, plugin.DOMAIN_TYPE_TICKET) {
-			scopes = append(scopes, devops.NewCicdScope(id, scope.Name))
+			scopes = append(scopes, ticket.NewBoard(id, scope.Name))
 		}
 	}
 
