@@ -18,12 +18,13 @@ limitations under the License.
 package archived
 
 import (
-	"github.com/apache/incubator-devlake/core/models/common"
 	"time"
+
+	"github.com/apache/incubator-devlake/core/models/migrationscripts/archived"
 )
 
 type Assignment struct {
-	common.NoPKModel
+	archived.NoPKModel
 	ConnectionId   uint64
 	IncidentNumber int    `gorm:"primaryKey"`
 	UserId         string `gorm:"primaryKey"`
