@@ -18,6 +18,7 @@ limitations under the License.
 package models
 
 import (
+	"github.com/apache/incubator-devlake/core/utils"
 	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 )
 
@@ -27,6 +28,11 @@ type SlackConn struct {
 	helper.AccessToken    `mapstructure:",squash"`
 }
 
+func (connection SlackConn) Sanitize() SlackConn {
+	connection.Token = utils.SanitizeString(connection.Token)
+	return connection
+}
+
 // SlackConnection holds SlackConn plus ID/Name for database storage
 type SlackConnection struct {
 	helper.BaseConnection `mapstructure:",squash"`
@@ -36,3 +42,20 @@ type SlackConnection struct {
 func (SlackConnection) TableName() string {
 	return "_tool_slack_connections"
 }
+
+func (connection SlackConnection) Sanitize() SlackConnection {
+	connection.SlackConn = connection.SlackConn.Sanitize()
+	return connection
+}
+
+func (connection *SlackConnection) MergeFromRequest(target *SlackConnection, body map[string]interface{}) error {
+	token := target.Token
+	if err := helper.DecodeMapStruct(body, target, true); err != nil {
+		return err
+	}
+	modifiedToken := target.Token
+	if modifiedToken == "" || modifiedToken == utils.SanitizeString(token) {
+		target.Token = token
+	}
+	return nil
+}
