@@ -26,8 +26,7 @@ type SlackApiParams struct {
 }
 
 type SlackOptions struct {
-	ConnectionId            uint64 `json:"connectionId"`
-	helper.CollectorOptions `mapstructure:",squash"`
+	ConnectionId uint64 `json:"connectionId"`
 }
 
 type SlackTaskData struct {
