@@ -111,7 +111,7 @@ func makeScopesV200(
 		sonarqubeProject := scopeDetail.Scope
 		// add board to scopes
 		domainBoard := &codequality.CqProject{
-			DomainEntity: domainlayer.DomainEntity{
+			DomainEntityExtended: domainlayer.DomainEntityExtended{
 				Id: didgen.NewDomainIdGenerator(&models.SonarqubeProject{}).Generate(sonarqubeProject.ConnectionId, sonarqubeProject.ProjectKey),
 			},
 			Name: sonarqubeProject.Name,
