@@ -80,6 +80,7 @@ func (p Sonarqube) GetTablesInfo() []dal.Tabler {
 		&models.SonarqubeConnection{},
 		&models.SonarqubeProject{},
 		&models.SonarqubeIssue{},
+		&models.SonarqubeIssueImpact{},
 		&models.SonarqubeIssueCodeBlock{},
 		&models.SonarqubeHotspot{},
 		&models.SonarqubeFileMetrics{},
@@ -102,6 +103,7 @@ func (p Sonarqube) SubTaskMetas() []plugin.SubTaskMeta {
 		tasks.ExtractAccountsMeta,
 		tasks.ConvertProjectsMeta,
 		tasks.ConvertIssuesMeta,
+		tasks.ConvertIssueImpactsMeta,
 		tasks.ConvertIssueCodeBlocksMeta,
 		tasks.ConvertHotspotsMeta,
 		tasks.ConvertFileMetricsMeta,
