@@ -36,5 +36,8 @@ func All() []plugin.MigrationScript {
 		new(modifyNameLength),
 		new(changeIssueComponentType),
 		new(increaseProjectKeyLength),
+		new(addOrgToConn),
+		new(addIssueImpacts),
+		new(extendSonarqubeFieldSize),
 	}
 }
