@@ -18,23 +18,24 @@ limitations under the License.
 package archived
 
 import (
+	"time"
+
 	"github.com/apache/incubator-devlake/core/models/migrationscripts/archived"
-	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 )
 
 type TapdSubWorkspace struct {
-	ConnectionId uint64          `gorm:"primaryKey;type:BIGINT  NOT NULL"`
-	Id           uint64          `gorm:"primaryKey;type:BIGINT;autoIncrement:false" json:"id,string"`
-	Name         string          `gorm:"type:varchar(255)" json:"name"`
-	PrettyName   string          `gorm:"type:varchar(255)" json:"pretty_name"`
-	Category     string          `gorm:"type:varchar(255)" json:"category"`
-	Status       string          `gorm:"type:varchar(255)" json:"status"`
-	Description  string          `json:"description"`
-	BeginDate    *helper.CSTTime `json:"begin_date"`
-	EndDate      *helper.CSTTime `json:"end_date"`
-	ExternalOn   string          `gorm:"type:varchar(255)" json:"external_on"`
-	ParentId     uint64          `gorm:"type:BIGINT" json:"parent_id,string"`
-	Creator      string          `gorm:"type:varchar(255)" json:"creator"`
+	ConnectionId uint64     `gorm:"primaryKey;type:BIGINT  NOT NULL"`
+	Id           uint64     `gorm:"primaryKey;type:BIGINT;autoIncrement:false" json:"id,string"`
+	Name         string     `gorm:"type:varchar(255)" json:"name"`
+	PrettyName   string     `gorm:"type:varchar(255)" json:"pretty_name"`
+	Category     string     `gorm:"type:varchar(255)" json:"category"`
+	Status       string     `gorm:"type:varchar(255)" json:"status"`
+	Description  string     `json:"description"`
+	BeginDate    *time.Time `json:"begin_date"`
+	EndDate      *time.Time `json:"end_date"`
+	ExternalOn   string     `gorm:"type:varchar(255)" json:"external_on"`
+	ParentId     uint64     `gorm:"type:BIGINT" json:"parent_id,string"`
+	Creator      string     `gorm:"type:varchar(255)" json:"creator"`
 	archived.NoPKModel
 }
 
