@@ -18,23 +18,24 @@ limitations under the License.
 package archived
 
 import (
+	"time"
+
 	"github.com/apache/incubator-devlake/core/models/migrationscripts/archived"
-	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 )
 
 type TapdTaskChangelog struct {
-	ConnectionId   uint64          `gorm:"primaryKey;type:BIGINT  NOT NULL"`
-	Id             uint64          `gorm:"primaryKey;type:BIGINT  NOT NULL;autoIncrement:false" json:"id,string"`
-	WorkspaceId    uint64          `json:"workspace_id,string"`
-	WorkitemTypeId uint64          `json:"workitem_type_id,string"`
-	Creator        string          `json:"creator" gorm:"type:varchar(255)"`
-	Created        *helper.CSTTime `json:"created"`
-	ChangeSummary  string          `json:"change_summary" gorm:"type:varchar(255)"`
-	Comment        string          `json:"comment"`
-	EntityType     string          `json:"entity_type" gorm:"type:varchar(255)"`
-	ChangeType     string          `json:"change_type" gorm:"type:varchar(255)"`
-	ChangeTypeText string          `json:"change_type_text" gorm:"type:varchar(255)"`
-	TaskId         uint64          `json:"task_id,string"`
+	ConnectionId   uint64     `gorm:"primaryKey;type:BIGINT  NOT NULL"`
+	Id             uint64     `gorm:"primaryKey;type:BIGINT  NOT NULL;autoIncrement:false" json:"id,string"`
+	WorkspaceId    uint64     `json:"workspace_id,string"`
+	WorkitemTypeId uint64     `json:"workitem_type_id,string"`
+	Creator        string     `json:"creator" gorm:"type:varchar(255)"`
+	Created        *time.Time `json:"created"`
+	ChangeSummary  string     `json:"change_summary" gorm:"type:varchar(255)"`
+	Comment        string     `json:"comment"`
+	EntityType     string     `json:"entity_type" gorm:"type:varchar(255)"`
+	ChangeType     string     `json:"change_type" gorm:"type:varchar(255)"`
+	ChangeTypeText string     `json:"change_type_text" gorm:"type:varchar(255)"`
+	TaskId         uint64     `json:"task_id,string"`
 	archived.NoPKModel
 	FieldChanges []TapdTaskChangelogItem `json:"field_changes" gorm:"-"`
 }
