@@ -18,21 +18,22 @@ limitations under the License.
 package archived
 
 import (
+	"time"
+
 	"github.com/apache/incubator-devlake/core/models/migrationscripts/archived"
-	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 )
 
 type TapdWorklog struct {
-	ConnectionId uint64          `gorm:"primaryKey;type:BIGINT  NOT NULL"`
-	Id           uint64          `gorm:"primaryKey;type:BIGINT  NOT NULL;autoIncrement:false" json:"id,string"`
-	WorkspaceId  uint64          `json:"workspace_id,string"`
-	EntityType   string          `gorm:"type:varchar(255)" json:"entity_type"`
-	EntityId     uint64          `json:"entity_id,string"`
-	Timespent    float32         `json:"timespent,string"`
-	Spentdate    *helper.CSTTime `json:"spentdate"`
-	Owner        string          `gorm:"type:varchar(255)" json:"owner"`
-	Created      *helper.CSTTime `json:"created"`
-	Memo         string          `json:"memo" gorm:"type:text"`
+	ConnectionId uint64     `gorm:"primaryKey;type:BIGINT  NOT NULL"`
+	Id           uint64     `gorm:"primaryKey;type:BIGINT  NOT NULL;autoIncrement:false" json:"id,string"`
+	WorkspaceId  uint64     `json:"workspace_id,string"`
+	EntityType   string     `gorm:"type:varchar(255)" json:"entity_type"`
+	EntityId     uint64     `json:"entity_id,string"`
+	Timespent    float32    `json:"timespent,string"`
+	Spentdate    *time.Time `json:"spentdate"`
+	Owner        string     `gorm:"type:varchar(255)" json:"owner"`
+	Created      *time.Time `json:"created"`
+	Memo         string     `json:"memo" gorm:"type:text"`
 	archived.NoPKModel
 }
 
