@@ -18,52 +18,57 @@ limitations under the License.
 package models
 
 import (
+	"encoding/json"
+	"time"
+
 	"github.com/apache/incubator-devlake/core/models/common"
 )
 
 type TapdStory struct {
-	ConnectionId    uint64          `gorm:"primaryKey"`
-	Id              uint64          `gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false" json:"id,string"`
-	WorkitemTypeId  uint64          `json:"workitem_type_id,string"`
-	Name            string          `gorm:"type:varchar(255)" json:"name"`
-	Description     string          `json:"description"`
-	WorkspaceId     uint64          `json:"workspace_id,string"`
-	Creator         string          `gorm:"type:varchar(255)"`
-	Created         *common.CSTTime `json:"created"`
-	Modified        *common.CSTTime `json:"modified" gorm:"index"`
-	Status          string          `json:"status" gorm:"type:varchar(255)"`
-	Owner           string          `json:"owner" gorm:"type:varchar(255)"`
-	Cc              string          `json:"cc" gorm:"type:varchar(255)"`
-	Begin           *common.CSTTime `json:"begin"`
-	Due             *common.CSTTime `json:"due"`
-	Size            int16           `json:"size,string"`
-	Priority        string          `gorm:"type:varchar(255)" json:"priority"`
-	Developer       string          `gorm:"type:varchar(255)" json:"developer"`
-	IterationId     int64           `json:"iteration_id,string"`
-	TestFocus       string          `json:"test_focus" gorm:"type:varchar(255)"`
-	Type            string          `json:"type" gorm:"type:varchar(255)"`
-	Source          string          `json:"source" gorm:"type:varchar(255)"`
-	Module          string          `json:"module" gorm:"type:varchar(255)"`
-	Version         string          `json:"version" gorm:"type:varchar(255)"`
-	Completed       *common.CSTTime `json:"completed"`
-	CategoryId      int64           `json:"category_id,string"`
-	Path            string          `gorm:"type:varchar(255)" json:"path"`
-	ParentId        uint64          `json:"parent_id,string"`
-	ChildrenId      string          `gorm:"type:text" json:"children_id"`
-	AncestorId      uint64          `json:"ancestor_id,string"`
-	BusinessValue   string          `gorm:"type:varchar(255)" json:"business_value"`
-	Effort          float32         `json:"effort,string"`
-	EffortCompleted float32         `json:"effort_completed,string"`
-	Exceed          float32         `json:"exceed,string"`
-	Remain          float32         `json:"remain,string"`
-	ReleaseId       uint64          `json:"release_id,string"`
-	Confidential    string          `gorm:"type:varchar(255)" json:"confidential"`
-	TemplatedId     uint64          `json:"templated_id,string"`
-	CreatedFrom     string          `gorm:"type:varchar(255)" json:"created_from"`
-	Feature         string          `gorm:"type:varchar(255)" json:"feature"`
-	StdStatus       string          `gorm:"type:varchar(20)"`
-	StdType         string          `gorm:"type:varchar(20)"`
-	Url             string          `gorm:"type:varchar(255)"`
+	AllFields       map[string]interface{} `gorm:"-"`
+	ConnectionId    uint64                 `gorm:"primaryKey"`
+	Id              uint64                 `gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false" json:"id,string"`
+	WorkitemTypeId  uint64                 `json:"workitem_type_id,string"`
+	Name            string                 `gorm:"type:varchar(255)" json:"name"`
+	Description     string                 `json:"description"`
+	WorkspaceId     uint64                 `json:"workspace_id,string"`
+	Creator         string                 `gorm:"type:varchar(255)"`
+	Created         *common.CSTTime        `json:"created"`
+	Modified        *common.CSTTime        `json:"modified" gorm:"index"`
+	Status          string                 `json:"status" gorm:"type:varchar(255)"`
+	Owner           string                 `json:"owner" gorm:"type:varchar(255)"`
+	Cc              string                 `json:"cc" gorm:"type:varchar(255)"`
+	Begin           *common.CSTTime        `json:"begin"`
+	Due             *common.CSTTime        `json:"due"`
+	Size            int16                  `json:"size,string"`
+	Priority        string                 `gorm:"type:varchar(255)" json:"priority"`
+	Developer       string                 `gorm:"type:varchar(255)" json:"developer"`
+	IterationId     int64                  `json:"iteration_id,string"`
+	TestFocus       string                 `json:"test_focus" gorm:"type:varchar(255)"`
+	Type            string                 `json:"type" gorm:"type:varchar(255)"`
+	Source          string                 `json:"source" gorm:"type:varchar(255)"`
+	Module          string                 `json:"module" gorm:"type:varchar(255)"`
+	Version         string                 `json:"version" gorm:"type:varchar(255)"`
+	Completed       *common.CSTTime        `json:"completed"`
+	CategoryId      int64                  `json:"category_id,string"`
+	Path            string                 `gorm:"type:varchar(255)" json:"path"`
+	ParentId        uint64                 `json:"parent_id,string"`
+	ChildrenId      string                 `gorm:"type:text" json:"children_id"`
+	AncestorId      uint64                 `json:"ancestor_id,string"`
+	BusinessValue   string                 `gorm:"type:varchar(255)" json:"business_value"`
+	Effort          float32                `json:"effort,string"`
+	EffortCompleted float32                `json:"effort_completed,string"`
+	Exceed          float32                `json:"exceed,string"`
+	Remain          float32                `json:"remain,string"`
+	ReleaseId       uint64                 `json:"release_id,string"`
+	Confidential    string                 `gorm:"type:varchar(255)" json:"confidential"`
+	TemplatedId     uint64                 `json:"templated_id,string"`
+	CreatedFrom     string                 `gorm:"type:varchar(255)" json:"created_from"`
+	Feature         string                 `gorm:"type:varchar(255)" json:"feature"`
+	StdStatus       string                 `gorm:"type:varchar(20)"`
+	StdType         string                 `gorm:"type:varchar(20)"`
+	Url             string                 `gorm:"type:varchar(255)"`
+	DueDate         *time.Time             `json:"due_date"`
 
 	AttachmentCount  int16  `json:"attachment_count,string"`
 	HasAttachment    string `json:"has_attachment" gorm:"type:varchar(255)"`
@@ -133,3 +138,15 @@ type TapdStory struct {
 func (TapdStory) TableName() string {
 	return "_tool_tapd_stories"
 }
+
+func (i *TapdStory) SetAllFields(raw json.RawMessage) error {
+	var storyBody struct {
+		Story map[string]interface{}
+	}
+	err := json.Unmarshal(raw, &storyBody)
+	if err != nil {
+		return err
+	}
+	i.AllFields = storyBody.Story
+	return nil
+}
