@@ -18,8 +18,9 @@ limitations under the License.
 package archived
 
 import (
+	"time"
+
 	"github.com/apache/incubator-devlake/core/models/migrationscripts/archived"
-	"github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 )
 
 type TeambitionTaskTag struct {
@@ -31,8 +32,8 @@ type TeambitionTaskTag struct {
 	Name           string `gorm:"type:varchar(100)"`
 	Color          string `gorm:"type:varchar(100)"`
 	IsArchived     bool
-	Created        *api.Iso8601Time
-	Updated        *api.Iso8601Time
+	Created        *time.Time
+	Updated        *time.Time
 
 	archived.NoPKModel
 }
