@@ -23,10 +23,13 @@ import (
 
 type TrelloScopeConfig struct {
 	common.ScopeConfig `mapstructure:",squash" json:",inline" gorm:"embedded"`
-	ConnectionId       uint64 `mapstructure:"connectionId" json:"connectionId"`
-	Name               string `mapstructure:"name" json:"name" gorm:"type:varchar(255);index:idx_name_trello,unique" validate:"required"`
 }
 
 func (TrelloScopeConfig) TableName() string {
 	return "_tool_trello_scope_configs"
 }
+
+func (t *TrelloScopeConfig) SetConnectionId(c *TrelloScopeConfig, connectionId uint64) {
+	c.ConnectionId = connectionId
+	c.ScopeConfig.ConnectionId = connectionId
+}
