@@ -91,6 +91,7 @@ func (p Zentao) GetTablesInfo() []dal.Tabler {
 		&models.ZentaoExecutionSummary{},
 		&models.ZentaoProductSummary{},
 		&models.ZentaoProjectStory{},
+		&models.ZentaoWorklog{},
 	}
 }
 
@@ -135,8 +136,7 @@ func (p Zentao) SubTaskMetas() []plugin.SubTaskMeta {
 
 		tasks.CollectTaskCommitsMeta,
 		tasks.ExtractTaskCommitsMeta,
-		tasks.CollectTaskRepoCommitsMeta,
-		tasks.ExtractTaskRepoCommitsMeta,
+		tasks.DBGetTaskRepoCommitsMeta,
 		tasks.ConvertTaskRepoCommitsMeta,
 
 		// product
@@ -151,18 +151,20 @@ func (p Zentao) SubTaskMetas() []plugin.SubTaskMeta {
 
 		tasks.CollectStoryCommitsMeta,
 		tasks.ExtractStoryCommitsMeta,
-		tasks.CollectStoryRepoCommitsMeta,
-		tasks.ExtractStoryRepoCommitsMeta,
+		tasks.DBGetStoryRepoCommitsMeta,
 		tasks.ConvertStoryRepoCommitsMeta,
 
 		tasks.CollectBugCommitsMeta,
 		tasks.ExtractBugCommitsMeta,
-		tasks.CollectBugRepoCommitsMeta,
-		tasks.ExtractBugRepoCommitsMeta,
+		tasks.DBGetBugRepoCommitsMeta,
 		tasks.ConvertBugRepoCommitsMeta,
 
 		tasks.DBGetChangelogMeta,
 		tasks.ConvertChangelogMeta,
+
+		tasks.CollectTaskWorklogsMeta,
+		tasks.ExtractTaskWorklogsMeta,
+		tasks.ConvertTaskWorklogsMeta,
 	}
 }
 
