@@ -73,6 +73,11 @@ type ZentaoConn struct {
 	DbMaxConns     int    `json:"dbMaxConns" mapstructure:"dbMaxConns"`
 }
 
+func (connection ZentaoConn) GetHash() string {
+	// zentao's token will expire after about 24min, so api client cannot be cached.
+	return ""
+}
+
 func (connection ZentaoConn) Sanitize() ZentaoConn {
 	connection.Password = ""
 	if connection.DbUrl != "" {
@@ -106,6 +111,10 @@ func (connection ZentaoConn) SanitizeDbUrl() string {
 	return dbUrl
 }
 
+func (connection ZentaoConnection) GetHash() string {
+	return connection.ZentaoConn.GetHash()
+}
+
 func (connection ZentaoConnection) Sanitize() ZentaoConnection {
 	connection.ZentaoConn = connection.ZentaoConn.Sanitize()
 	return connection
