@@ -108,6 +108,9 @@ func ConvertTask(taskCtx plugin.SubTaskContext) errors.Error {
 			if toolEntity.AssignedToId != 0 {
 				domainEntity.AssigneeId = accountIdGen.Generate(data.Options.ConnectionId, toolEntity.AssignedToId)
 			}
+			if toolEntity.DueDate != nil {
+				domainEntity.DueDate = toolEntity.DueDate
+			}
 			closedDate := toolEntity.ClosedDate
 			openedDate := toolEntity.OpenedDate
 			if closedDate != nil && closedDate.ToTime().After(openedDate.ToTime()) {
