@@ -18,9 +18,10 @@ limitations under the License.
 package tasks
 
 import (
-	"github.com/spf13/cast"
 	"reflect"
 
+	"github.com/spf13/cast"
+
 	"github.com/apache/incubator-devlake/core/dal"
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/crossdomain"
@@ -35,7 +36,7 @@ var _ plugin.SubTaskEntryPoint = ConvertTaskRepoCommits
 var ConvertTaskRepoCommitsMeta = plugin.SubTaskMeta{
 	Name:             "convertTaskRepoCommits",
 	EntryPoint:       ConvertTaskRepoCommits,
-	EnabledByDefault: true,
+	EnabledByDefault: false,
 	Description:      "convert Zentao task repo commits",
 	DomainTypes:      []string{plugin.DOMAIN_TYPE_TICKET},
 }
