@@ -16,18 +16,18 @@
 # limitations under the License.
 #
 
-cd "${0%/*}" # make sure we're in the correct dir
+if [ -z "$1" ]; then
+  cd "$(dirname "$0")"
+  cd plugins
+else
+  cd "$1"
+fi
 
-poetry config virtualenvs.create true
-
-for plugin_dir in $(ls -d plugins/*/*.toml); do
-  plugin_dir=$(dirname $plugin_dir)
-  echo "installing dependencies of python plugin in: $plugin_dir" &&\
-  cd "$plugin_dir" &&\
-  poetry install &&\
-  cd -
+for plugin_dir in $(ls -d */build.sh); do
+  echo "Building remote plugin: $plugin_dir" &&\
+  $plugin_dir
   exit_code=$?
   if [ $exit_code != 0 ]; then
     exit $exit_code
   fi
-done
\ No newline at end of file
+done
