@@ -78,7 +78,9 @@ class AzureDevOpsAPI(API):
         return self.get(org, project, '_apis/git/repositories', repo_id, 'commits')
 
     def builds(self, org: str, project: str, repository_id: str, provider: str):
-        return self.get(org, project, '_apis/build/builds', repositoryId=repository_id, repositoryType=provider, deletedFilter='excludeDeleted')
+        return self.get(org, project, '_apis/build/builds', repositoryId=repository_id, repositoryType=provider,
+                        deletedFilter='excludeDeleted',
+                        queryOrder="finishTimeDescending")
 
     def jobs(self, org: str, project: str, build_id: int):
         return self.get(org, project, '_apis/build/builds', build_id, 'timeline')
