@@ -13,22 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from http import HTTPStatus
 from typing import Iterable
 
-from http import HTTPStatus
-
+import pydevlake.domain_layer.devops as devops
 from azuredevops.api import AzureDevOpsAPI
 from azuredevops.models import Job, Build, GitRepository
 from azuredevops.streams.builds import Builds
 from pydevlake import Context, Substream, DomainType
 from pydevlake.api import APIException
-import pydevlake.domain_layer.devops as devops
 
 
 class Jobs(Substream):
     tool_model = Job
     domain_types = [DomainType.CICD]
     parent_stream = Builds
+    domain_models = [devops.CICDTask]
 
     def collect(self, state, context, parent: Build) -> Iterable[tuple[object, dict]]:
         repo: GitRepository = context.scope
@@ -50,27 +50,33 @@ class Jobs(Substream):
         for raw_job in response.json["records"]:
             if raw_job["type"] == "Job":
                 raw_job["build_id"] = parent.domain_id()
+                raw_job["x_request_url"] = response.get_url_with_query_string()
+                raw_job["x_request_input"] = {
+                    "OrgId": repo.org_id,
+                    "ProjectId": repo.project_id,
+                    "BuildId": parent.id,
+                }
                 yield raw_job, state
 
     def convert(self, j: Job, ctx: Context) -> Iterable[devops.CICDPipeline]:
         if not j.start_time:
             return
 
-        result = None
+        result = devops.CICDResult.RESULT_DEFAULT
         if j.result == Job.JobResult.Abandoned:
-            result = devops.CICDResult.ABORT
+            result = devops.CICDResult.RESULT_DEFAULT
         elif j.result == Job.JobResult.Canceled:
-            result = devops.CICDResult.ABORT
+            result = devops.CICDResult.FAILURE
         elif j.result == Job.JobResult.Failed:
             result = devops.CICDResult.FAILURE
         elif j.result == Job.JobResult.Skipped:
-            result = devops.CICDResult.ABORT
+            result = devops.CICDResult.RESULT_DEFAULT
         elif j.result == Job.JobResult.Succeeded:
             result = devops.CICDResult.SUCCESS
         elif j.result == Job.JobResult.SucceededWithIssues:
             result = devops.CICDResult.FAILURE
 
-        status = None
+        status = devops.CICDStatus.STATUS_OTHER
         if j.state == Job.JobState.Completed:
             status = devops.CICDStatus.DONE
         elif j.state == Job.JobState.InProgress:
@@ -81,21 +87,25 @@ class Jobs(Substream):
         type = devops.CICDType.BUILD
         if ctx.scope_config.deployment_pattern and ctx.scope_config.deployment_pattern.search(j.name):
             type = devops.CICDType.DEPLOYMENT
-        environment = devops.CICDEnvironment.TESTING
-        if ctx.scope_config.production_pattern and ctx.scope_config.production_pattern.search(j.name):
-            environment = devops.CICDEnvironment.PRODUCTION
+        environment = devops.CICDEnvironment.PRODUCTION
+        if ctx.scope_config.production_pattern is not None and ctx.scope_config.production_pattern.search(
+                j.name) is None:
+            environment = None
 
         if j.finish_time:
-            duration_sec = abs(j.finish_time.second-j.start_time.second)
+            duration_sec = abs(j.finish_time.timestamp() - j.start_time.timestamp())
         else:
-            duration_sec = 0
+            duration_sec = float(0.0)
 
         yield devops.CICDTask(
             id=j.id,
             name=j.name,
             pipeline_id=j.build_id,
             status=status,
+            original_status=str(j.state),
+            original_result=str(j.result),
             created_date=j.start_time,
+            started_date=j.start_time,
             finished_date=j.finish_time,
             result=result,
             type=type,
