@@ -17,16 +17,30 @@
 import sys
 import logging
 
+CRITICAL = logging.CRITICAL
+FATAL = logging.FATAL
+ERROR = logging.ERROR
+WARNING = logging.WARNING
+INFO = logging.INFO
+DEBUG = logging.DEBUG
+NOTSET = logging.NOTSET
+
+# mappings from main Go server to Python logging levels
+log_levels = {
+    'debug': DEBUG,
+    'info': INFO,
+    'warn': WARNING,
+    'error': ERROR,
+}
 
 stdout_handler = logging.StreamHandler(sys.stdout)
 stdout_handler.addFilter(lambda rec: rec.levelno < logging.ERROR)
 
-
 stderr_handler = logging.StreamHandler(sys.stderr)
 stderr_handler.addFilter(lambda rec: rec.levelno >= logging.ERROR)
 
 logging.basicConfig(
-    level=logging.DEBUG,
+    level=INFO, # default
     format='%(levelname)s: %(message)s',
     handlers=[stdout_handler, stderr_handler]
 )
