@@ -68,7 +68,7 @@ class ToolTable(SQLModel):
 
 
 class Connection(ToolTable, Model):
-    name: str
+    name: str = Field(unique=True)
     proxy: Optional[AnyUrl]
 
     @validator('proxy', pre=True)
@@ -103,7 +103,7 @@ class RawModel(SQLModel):
     id: int = Field(primary_key=True)
     params: str = b''
     data: bytes
-    url: str = b''
+    url: str = Field(default=b'', sa_column=Column(Text))
     input: bytes = b''
     created_at: datetime = Field(default_factory=datetime.now)
 
