@@ -78,7 +78,11 @@ def assert_stream_convert(plugin: Union[Plugin, Type[Plugin]], stream_name: str,
     if not isinstance(domain_models, (Iterable, Generator)):
         domain_models = [domain_models]
     for res, exp in zip(domain_models, expected):
-        assert res == exp
+        if (hasattr(res, "__getitem__") and res[0] == "updated_at") or (
+                hasattr(exp, "__getitem__") and exp[0] == "updated_at"):
+            pass
+        else:
+            assert res == exp
 
 
 def assert_stream_run(stream: Stream, connection: Connection, scope: ToolScope, scope_config: ScopeConfig):
