@@ -72,6 +72,30 @@ func GetTaskByPipeline(c *gin.Context) {
 	shared.ApiOutputSuccess(c, getTaskResponse{Tasks: tasks, Count: len(tasks)}, http.StatusOK)
 }
 
+// GetSubtasksByPipeline return most recent subtasks
+// @Summary Get subtasks, only the most recent subtasks will be returned
+// @Tags framework/tasks
+// @Accept application/json
+// @Param pipelineId path int true "pipelineId"
+// @Success 200  {object} models.SubTasksOuput
+// @Failure 400  {object} shared.ApiBody "Bad Request"
+// @Failure 500  {object} shared.ApiBody "Internal Error"
+// @Router /pipelines/{pipelineId}/subtasks [get]
+func GetSubtaskByPipeline(c *gin.Context) {
+	pipelineId, err := strconv.ParseUint(c.Param("pipelineId"), 10, 64)
+	if err != nil {
+		shared.ApiOutputError(c, errors.BadInput.Wrap(err, "invalid pipeline ID format"))
+		return
+	}
+	subTasksOuput, err := services.GetSubTasksInfo(pipelineId, true, nil)
+	if err != nil {
+		shared.ApiOutputError(c, errors.Default.Wrap(err, "error getting tasks"))
+		return
+	}
+
+	shared.ApiOutputSuccess(c, subTasksOuput, http.StatusOK)
+}
+
 // RerunTask rerun the specified task.
 // @Summary rerun task
 // @Tags framework/tasks
