@@ -18,6 +18,7 @@ limitations under the License.
 package helper
 
 import (
+	"github.com/apache/incubator-devlake/core/errors"
 	"os"
 	"path/filepath"
 )
@@ -27,25 +28,30 @@ var (
 	Shell       = ""
 )
 
-func LocalInit() {
+func init() {
+	Shell = "/bin/sh"
+	var err errors.Error
+	ProjectRoot, err = NormalizeBaseDirectory()
+	if err != nil {
+		panic(err.Error())
+	}
+}
+
+func NormalizeBaseDirectory() (string, errors.Error) {
 	pwd, err := os.Getwd()
 	if err != nil {
-		panic(err)
+		return "", errors.Convert(err)
 	}
 	for {
 		dir := filepath.Base(pwd)
 		if dir == "" {
-			panic("base repo directory not found")
+			return "", errors.Default.New("base repo directory not found")
 		}
-		if dir == "lake" || dir == "incubator-devlake" {
-			ProjectRoot = pwd
+		if dir == "backend" {
 			break
 		}
 		pwd = filepath.Dir(pwd)
 	}
-	Shell = "/bin/sh"
-	err = os.Chdir(ProjectRoot)
-	if err != nil {
-		panic(err)
-	}
+	err = os.Chdir(pwd)
+	return pwd, errors.Convert(err)
 }
