@@ -31,10 +31,16 @@ import (
 
 // IsWSL FIXME
 func IsWSL() bool {
-	lines, err := readFile("/proc/version")
+	file, err := os.Open("/proc/version")
 	if err != nil {
 		return false
 	}
+	defer file.Close()
+	var lines []string
+	scanner := bufio.NewScanner(file)
+	for scanner.Scan() {
+		lines = append(lines, scanner.Text())
+	}
 	for _, line := range lines {
 		l := strings.ToLower(line)
 		if strings.Contains(l, "microsoft") {
@@ -85,17 +91,3 @@ func Contains[T any](list []T, elem any) bool {
 	}
 	return false
 }
-
-func readFile(path string) ([]string, error) {
-	file, err := os.Open(path)
-	if err != nil {
-		return nil, err
-	}
-	defer file.Close()
-	var lines []string
-	scanner := bufio.NewScanner(file)
-	for scanner.Scan() {
-		lines = append(lines, scanner.Text())
-	}
-	return lines, scanner.Err()
-}
