@@ -15,29 +15,13 @@ See the License for the specific language governing permissions and
 limitations under the License.
 */
 
-package test
+package main
 
 import (
 	"github.com/apache/incubator-devlake/core/config"
-	"github.com/apache/incubator-devlake/core/plugin"
-	"github.com/apache/incubator-devlake/server/services"
+	"github.com/apache/incubator-devlake/test/helper"
 )
 
-func init() {
-	v := config.GetConfig()
-	encKey := v.GetString(plugin.EncodeKeyEnvStr)
-	if encKey == "" {
-		// Randomly generate a bunch of encryption keys and set them to config
-		encKey = plugin.RandomEncKey()
-		v.Set(plugin.EncodeKeyEnvStr, encKey)
-		err := config.WriteConfig(v)
-		if err != nil {
-			panic(err)
-		}
-	}
-	services.InitResources()
-	err := services.GetMigrator().Execute()
-	if err != nil {
-		panic(err)
-	}
+func main() {
+	helper.InitDB(config.GetConfig().GetString("E2E_DB_URL"))
 }
