@@ -16,28 +16,28 @@
  *
  */
 
-import { Icon } from '@blueprintjs/core';
+import { WarningOutlined } from '@ant-design/icons';
+import { Space } from 'antd';
 import styled from 'styled-components';
 
 const Wrapper = styled.div`
   display: flex;
   align-items: center;
-
-  & > .bp4-icon {
-    margin-right: 8px;
-  }
 `;
 
 interface Props {
   style?: React.CSSProperties;
+  size?: number;
   content: React.ReactNode;
 }
 
-export const Message = ({ style, content }: Props) => {
+export const Message = ({ style, size = 20, content }: Props) => {
   return (
     <Wrapper style={style}>
-      <Icon icon="warning-sign" size={24} color="#f4be55" />
-      <span>{content}</span>
+      <Space>
+        <WarningOutlined style={{ fontSize: size, color: '#f4be55' }} />
+        <span>{content}</span>
+      </Space>
     </Wrapper>
   );
 };
