@@ -16,8 +16,7 @@
  *
  */
 
+export * from './extend-redux';
 export * from './use-auto-refresh';
-export * from './use-connections';
 export * from './use-refresh-data';
-export * from './use-tips';
 export * from './user-proxy-prefix';
