@@ -17,8 +17,27 @@
  */
 
 import ReactDOM from 'react-dom';
+import { Provider } from 'react-redux';
+import { RouterProvider } from 'react-router-dom';
+import { ConfigProvider } from 'antd';
 
-import { App } from './App';
+import { PageLoading } from '@/components';
+
+import { store } from './app/store';
+import { router } from './app/routrer';
 import './index.css';
 
-ReactDOM.render(<App />, document.getElementById('root'));
+ReactDOM.render(
+  <ConfigProvider
+    theme={{
+      token: {
+        colorPrimary: import.meta.env.DEVLAKE_COLOR_CUSTOM ?? '#7497F7',
+      },
+    }}
+  >
+    <Provider store={store}>
+      <RouterProvider router={router} fallbackElement={<PageLoading />} />
+    </Provider>
+  </ConfigProvider>,
+  document.getElementById('root'),
+);
