@@ -15,28 +15,11 @@
  * limitations under the License.
  *
  */
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
 
 import { useState, useEffect } from 'react';
-import { FormGroup, Switch, NumericInput } from '@blueprintjs/core';
+import { Switch, InputNumber } from 'antd';
 
-import { ExternalLink } from '@/components';
+import { Block, ExternalLink } from '@/components';
 
 import * as S from './styled';
 
@@ -72,8 +55,7 @@ export const ConnectionRateLimit = ({
     setChecked(value ? true : false);
   }, [value]);
 
-  const handleChange = (e: React.FormEvent<HTMLInputElement>) => {
-    const checked = (e.target as HTMLInputElement).checked;
+  const handleChange = (checked: boolean) => {
     if (checked) {
       setValue(defaultValue);
     } else {
@@ -82,29 +64,29 @@ export const ConnectionRateLimit = ({
     setChecked(checked);
   };
 
-  const handleChangeValue = (value: number) => {
-    setValue(value);
+  const handleChangeValue = (value: number | null) => {
+    setValue(value ?? 0);
   };
 
   return (
-    <FormGroup
-      label={<S.Label>Custom Rate Limit</S.Label>}
-      subLabel={
-        <S.LabelDescription>
+    <Block
+      title="Custom Rate Limit"
+      description={
+        <>
           {subLabel} {learnMore && <ExternalLink link={learnMore}>Learn more</ExternalLink>}
-        </S.LabelDescription>
+        </>
       }
     >
       <S.RateLimit>
         <Switch checked={checked} onChange={handleChange} />
         {checked && (
           <>
-            <NumericInput buttonPosition="none" min={0} value={value} onValueChange={handleChangeValue} />
+            <InputNumber min={0} value={value} onChange={handleChangeValue} />
             <span>requests/hour</span>
           </>
         )}
       </S.RateLimit>
       {checked && externalInfo && <S.RateLimitInfo dangerouslySetInnerHTML={{ __html: externalInfo }} />}
-    </FormGroup>
+    </Block>
   );
 };
