@@ -18,8 +18,11 @@
 
 export * from './connection-form';
 export * from './connection-list';
+export * from './connection-select';
 export * from './connection-status';
 export * from './data-scope-remote';
 export * from './data-scope-select';
+export * from './plugin-name';
+export * from './scope-config';
 export * from './scope-config-form';
 export * from './scope-config-select';
