@@ -16,7 +16,6 @@
  *
  */
 
-export * from './types';
-export * from './utils';
 export * from './components';
-export * from './config';
+export * from './register';
+export * from './utils';
