@@ -17,6 +17,7 @@
  */
 
 import { useParams } from 'react-router-dom';
+import { Helmet } from 'react-helmet';
 
 import { PageHeader } from '@/components';
 import { PATHS } from '@/config';
@@ -25,6 +26,8 @@ import { FromEnum } from '../types';
 
 import { BlueprintDetail } from './blueprint-detail';
 
+const brandName = import.meta.env.DEVLAKE_BRAND_NAME ?? 'DevLake';
+
 export const BlueprintDetailPage = () => {
   const { id } = useParams() as { id: string };
 
@@ -36,6 +39,11 @@ export const BlueprintDetailPage = () => {
         { name: id, path: PATHS.BLUEPRINT(id) },
       ]}
     >
+      <Helmet>
+        <title>
+          {`Blueprints:${id}`} - {brandName}
+        </title>
+      </Helmet>
       <BlueprintDetail id={id} from={FromEnum.blueprint} />
     </PageHeader>
   );
