@@ -16,6 +16,7 @@
  *
  */
 
+import { redirect } from 'react-router-dom';
 import { intersection } from 'lodash';
 
 import API from '@/api';
@@ -26,6 +27,12 @@ type Props = {
 };
 
 export const layoutLoader = async ({ request }: Props) => {
+  const onboard = await API.store.get('onboard');
+
+  if (!onboard) {
+    return redirect('/onboard');
+  }
+
   let fePlugins = getRegisterPlugins();
   const bePlugins = await API.plugin.list();
 
