@@ -23,7 +23,7 @@ import svgr from 'vite-plugin-svgr';
 
 // https://vitejs.dev/config/
 export default defineConfig({
-  plugins: [svgr(), react()],
+  plugins: [react(), svgr()],
 
   envPrefix: 'DEVLAKE_',
 
